import React from 'react';
import { IFieldProps } from '../utils/withField';
import { IBaseSelectProps } from './BaseSelect';
import { IOption } from './Select';
export interface IMultiSelectProps<V extends string = string> extends Omit<IBaseSelectProps<V>, 'value' | 'component' | 'options' | 'onChange' | 'selectMarker'> {
    /**
     * Selects items in the dropdown menu.
     * Must pre-exist in the dropdown menu and written in lowercase.
     * Otherwise no value is selected.
     */
    readonly value: ReadonlyArray<V>;
    /**
     * Used to create an array of selectable options.
     */
    readonly options: ReadonlyArray<IOption<V>>;
    /**
     * Executes a JavaScript when a user changes the selected option of an element.
     */
    readonly onChange?: (value: ReadonlyArray<V>) => void;
    /**
     * Placeholder text when no value has been selected.
     */
    readonly placeholder?: string;
}
export declare function MultiSelect<V extends string = string>({ value, options, onChange, placeholder, ...props }: IMultiSelectProps<V>): JSX.Element;
export declare const MultiSelectField: <V extends string = string>(props: IFieldProps & IMultiSelectProps<V>) => React.ReactElement<any, any> | null;
