import { ToastId } from './toastActions';
import { IBaseToast } from './Toast';
import { IButtonLinkProps, IALinkProps } from '../Link';
import { IconType } from '../Icon';
export interface ISimpleToast {
    readonly label: string;
    readonly message?: string;
    readonly onClose?: (id: ToastId) => void;
    readonly duration?: number;
}
export interface IActionToast extends ISimpleToast {
    readonly action: {
        readonly icon: IconType;
        readonly text: string;
        readonly link: IButtonLinkProps | IALinkProps;
    };
}
export interface IProgressToast extends ISimpleToast {
    readonly progress: {
        readonly value: number;
        readonly label: string;
    };
}
export declare type IToast = ISimpleToast | IActionToast;
declare type ToastCreator<T = IToast> = (toast: T) => IBaseToast;
declare type SimpleToastCreator = ToastCreator<ISimpleToast>;
declare type ActionToastCreator = ToastCreator<IActionToast>;
declare type ProgressToastCreator = ToastCreator<IProgressToast>;
export declare const createSuccessToast: SimpleToastCreator;
export declare const createErrorToast: SimpleToastCreator;
export declare const createWarningToast: SimpleToastCreator;
export declare const createInfoToast: SimpleToastCreator;
export declare const createActionToast: ActionToastCreator;
export declare const createLoadingToast: SimpleToastCreator;
export declare const createProgressToast: ProgressToastCreator;
export {};
